==> contentsquare-0.5.0.tar.gz: test/src/modules/screengraph/element_extension_test.dart <==
import 'package:contentsquare/src/modules/screengraph/element_extension.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter_test/flutter_test.dart';

main() {
  group(
    'ElementExtension.directRenderObject',
    () {
      testWidgets(
        'Should return null when the element is not a RenderObjectElement',
        (WidgetTester tester) async {
          const _key = Key('text');

          await tester.pumpWidget(
            const MaterialApp(
              home: Text(
                'Hello',
                key: _key,
              ),
            ),
          );

          final element = tester.element(find.byKey(_key));

          expect(element.directRenderObject, null);
        },
      );

      testWidgets(
        'Should return the RenderObject associated to the given element when the element is a RenderObjectElement',
        (WidgetTester tester) async {
          const _key = Key('text');

          await tester.pumpWidget(
            const MaterialApp(
              home: ClipRRect(key: _key),
            ),
          );

          final element = tester.element(find.byKey(_key));

          expect(element.directRenderObject, isA<RenderClipRRect>());
        },
      );
    },
  );
  group(
    'ElementExtension.containsGlobalPosition',
    () {
      testWidgets(
        'Should return [MaybeResult.yes] when the element global frame contains the global position',
        (WidgetTester tester) async {
          const _topHalfKey = ValueKey('TopHalf');
          await tester.pumpWidget(
            MaterialApp(
              home: Column(
                children: const <Widget>[
                  Expanded(
                    child: SizedBox.expand(key: _topHalfKey),
                  ),
                  Expanded(child: SizedBox.expand()),
                ],
              ),
            ),
          );

          final screenSize = WidgetsBinding.instance!.renderView.size;
          final topQuarterCenter = Offset(
            screenSize.width / 2,
            screenSize.height / 4,
          );

          final topHalfElement = tester.element(find.byKey(_topHalfKey));

          expect(
            topHalfElement.containsGlobalPosition(topQuarterCenter),
            MaybeResult.yes,
          );
        },
      );

      testWidgets(
        'Should return [MaybeResult.no] when the element global frame does not contain the global position',
        (WidgetTester tester) async {
          const _topHalfKey = ValueKey('TopHalf');
          await tester.pumpWidget(
            MaterialApp(
              home: Column(
                children: const <Widget>[
                  Expanded(
                    child: SizedBox.expand(key: _topHalfKey),
                  ),
                  Expanded(child: SizedBox.expand()),
                ],
              ),
            ),
          );

          final screenSize = WidgetsBinding.instance!.renderView.size;
          final bottomQuarterCenter = Offset(
            screenSize.width / 2,
            3 * screenSize.height / 4,
          );

          final topHalfElement = tester.element(find.byKey(_topHalfKey));

          expect(
            topHalfElement.containsGlobalPosition(bottomQuarterCenter),
            MaybeResult.no,
          );
        },
      );

      testWidgets(
        'Should return [MaybeResult.unknown] when the element does not have a direct render object',
        (WidgetTester tester) async {
          const _screenKey = ValueKey('Screen');
          await tester.pumpWidget(
            MaterialApp(
              home: Container(
                key: _screenKey,
                child: const Center(
                  child: Text('Hello'),
                ),
              ),
            ),
          );

          final screenSize = WidgetsBinding.instance!.renderView.size;
          final center = Offset(screenSize.width / 2, screenSize.height / 2);

          final screenElement = tester.element(find.byKey(_screenKey));

          expect(
            screenElement.containsGlobalPosition(center),
            MaybeResult.unknown,
          );
        },
      );
    },
  );

  group(
    'ElementExtension.visitChildrenFromTVP',
    () {
      testWidgets(
        'Should call visit on each child element when visit always returns false',
        (WidgetTester tester) async {
          const _columnKey = ValueKey('Column');
          const _childrenKeys = [
            ValueKey('Child1'),
            ValueKey('Child2'),
            ValueKey('Child3'),
          ];
          await tester.pumpWidget(
            MaterialApp(
              home: Column(
                key: _columnKey,
                children: <Widget>[
                  SizedBox(key: _childrenKeys[0]),
                  SizedBox(key: _childrenKeys[1]),
                  SizedBox(key: _childrenKeys[2]),
                ],
              ),
            ),
          );

          final columnElement = tester.element(find.byKey(_columnKey));

          var visitedChildrenKeys = <ValueKey>[];
          columnElement.visitChildrenFromTVP(
            elementTVP: 'ColumnTVP',
            visit: (childElement, _) {
              visitedChildrenKeys.add(childElement.widget.key as ValueKey);

              return false;
            },
          );

          expect(visitedChildrenKeys, _childrenKeys);
        },
      );

      testWidgets(
        'Should stop calling visit on child element when visit returns true',
        (WidgetTester tester) async {
          const _columnKey = ValueKey('Column');
          await tester.pumpWidget(
            MaterialApp(
              home: Column(
                key: _columnKey,
                children: const <Widget>[
                  SizedBox(),
                  SizedBox(),
                  SizedBox(),
                ],
              ),
            ),
          );

          final columnElement = tester.element(find.byKey(_columnKey));
          final columnChildrenElements = <Element>[];
          columnElement.visitChildren(columnChildrenElements.add);

          var visitedChildren = <Element>[];
          columnElement.visitChildrenFromTVP(
            elementTVP: 'ColumnTVP',
            visit: (childElement, _) {
              visitedChildren.add(childElement);

              // Return true to stop visiting more children.
              return true;
            },
          );

          expect(visitedChildren.length, 1);
          expect(visitedChildren.first, columnChildrenElements.first);
        },
      );

      testWidgets(
        'Should create a new elementTVP for each child element',
        (WidgetTester tester) async {
          const _columnKey = ValueKey('Column');
          await tester.pumpWidget(
            MaterialApp(
              home: Column(
                key: _columnKey,
                children: const <Widget>[
                  SizedBox(),
                  SizedBox(),
                  ColoredBox(color: Colors.red),
                ],
              ),
            ),
          );

          final columnElement = tester.element(find.byKey(_columnKey));

          var visitedChildrenTVP = <String>[];
          columnElement.visitChildrenFromTVP(
            elementTVP: 'ColumnTVP',
            visit: (_, childTVP) {
              visitedChildrenTVP.add(childTVP);

              return false;
            },
          );

          expect(
            visitedChildrenTVP,
            [
              'ColumnTVP>SizedBox:eq(0)',
              'ColumnTVP>SizedBox:eq(1)',
              'ColumnTVP>ColoredBox:eq(0)',
            ],
          );
        },
      );

      group(
        'RenderSliverMultiBoxAdaptor',
        () {
          testWidgets(
            'Should use the index of [RenderIndexedSemantics] children',
            (WidgetTester tester) async {
              const _listKey = ValueKey('ListView');
              const itemHeight = 200.0;
              await tester.pumpWidget(
                MaterialApp(
                  home: ListView(
                    key: _listKey,
                    children: List.generate(
                      400,
                      (index) => SizedBox(
                        key: ValueKey('SizedBox_$index'),
                        height: itemHeight,
                      ),
                    ),
                  ),
                ),
              );

              // Scroll so that the default index does not match the index of the
              // [RenderIndexedSemantics]s.
              await tester.scrollUntilVisible(
                find.byKey(const ValueKey('SizedBox_30')),
                itemHeight,
              );

              final columnElement = tester.element(
                find.byElementType(SliverMultiBoxAdaptorElement),
              );

              var visitedChildrenTVP = <String>[];
              columnElement.visitChildrenFromTVP(
                elementTVP: 'ListViewTVP',
                visit: (_, childTVP) {
                  visitedChildrenTVP.add(childTVP);

                  return false;
                },
              );

              expect(
                visitedChildrenTVP,
                [
                  'ListViewTVP>KeyedSubtree:eq(26)',
                  'ListViewTVP>KeyedSubtree:eq(27)',
                  'ListViewTVP>KeyedSubtree:eq(28)',
                  'ListViewTVP>KeyedSubtree:eq(29)',
                  'ListViewTVP>KeyedSubtree:eq(30)',
                  'ListViewTVP>KeyedSubtree:eq(31)',
                  'ListViewTVP>KeyedSubtree:eq(32)',
                ],
              );
            },
          );
        },
      );
    },
  );
}

==> contentsquare-1.0.1.tar.gz: test/src/modules/screengraph/element_extension_test.dart <==
import 'package:contentsquare/src/modules/screengraph/element_extension.dart';
import 'package:contentsquare/src/modules/screengraph/widgets_binding.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter_test/flutter_test.dart';

main() {
  group(
    'ElementExtension.directRenderObject',
    () {
      testWidgets(
        'Should return null when the element is not a RenderObjectElement',
        (WidgetTester tester) async {
          const _key = Key('text');

          await tester.pumpWidget(
            const MaterialApp(
              home: Text(
                'Hello',
                key: _key,
              ),
            ),
          );

          final element = tester.element(find.byKey(_key));

          expect(element.directRenderObject, null);
        },
      );

      testWidgets(
        'Should return the RenderObject associated to the given element when the element is a RenderObjectElement',
        (WidgetTester tester) async {
          const _key = Key('text');

          await tester.pumpWidget(
            const MaterialApp(
              home: ClipRRect(key: _key),
            ),
          );

          final element = tester.element(find.byKey(_key));

          expect(element.directRenderObject, isA<RenderClipRRect>());
        },
      );
    },
  );
  group(
    'ElementExtension.containsGlobalPosition',
    () {
      testWidgets(
        'Should return [MaybeResult.yes] when the element global frame contains the global position',
        (WidgetTester tester) async {
          const _topHalfKey = ValueKey('TopHalf');
          await tester.pumpWidget(
            MaterialApp(
              home: Column(
                children: const <Widget>[
                  Expanded(
                    child: SizedBox.expand(key: _topHalfKey),
                  ),
                  Expanded(child: SizedBox.expand()),
                ],
              ),
            ),
          );

          final screenSize =
              WidgetsBindingExtension.safeInstance!.renderView.size;
          final topQuarterCenter = Offset(
            screenSize.width / 2,
            screenSize.height / 4,
          );

          final topHalfElement = tester.element(find.byKey(_topHalfKey));

          expect(
            topHalfElement.containsGlobalPosition(topQuarterCenter),
            MaybeResult.yes,
          );
        },
      );

      testWidgets(
        'Should return [MaybeResult.no] when the element global frame does not contain the global position',
        (WidgetTester tester) async {
          const _topHalfKey = ValueKey('TopHalf');
          await tester.pumpWidget(
            MaterialApp(
              home: Column(
                children: const <Widget>[
                  Expanded(
                    child: SizedBox.expand(key: _topHalfKey),
                  ),
                  Expanded(child: SizedBox.expand()),
                ],
              ),
            ),
          );

          final screenSize =
              WidgetsBindingExtension.safeInstance!.renderView.size;
          final bottomQuarterCenter = Offset(
            screenSize.width / 2,
            3 * screenSize.height / 4,
          );

          final topHalfElement = tester.element(find.byKey(_topHalfKey));

          expect(
            topHalfElement.containsGlobalPosition(bottomQuarterCenter),
            MaybeResult.no,
          );
        },
      );

      testWidgets(
        'Should return [MaybeResult.unknown] when the element does not have a direct render object',
        (WidgetTester tester) async {
          const _screenKey = ValueKey('Screen');
          await tester.pumpWidget(
            MaterialApp(
              home: Container(
                key: _screenKey,
                child: const Center(
                  child: Text('Hello'),
                ),
              ),
            ),
          );

          final screenSize =
              WidgetsBindingExtension.safeInstance!.renderView.size;
          final center = Offset(screenSize.width / 2, screenSize.height / 2);

          final screenElement = tester.element(find.byKey(_screenKey));

          expect(
            screenElement.containsGlobalPosition(center),
            MaybeResult.unknown,
          );
        },
      );
    },
  );
}
